@@ -9,7 +9,7 @@ import click
 import requests
 from datetime import datetime
 from typing import Optional, Tuple
-from pydantic import BaseModel  # type: ignore
+from pydantic import BaseModel
 import yaml
 
 from treebeard.version import get_version
@@ -153,8 +153,9 @@ def get_service_status_message(service_status_url: str) -> Optional[str]:
     return None
 
 
-class TreebeardConfig(BaseModel):  # type: ignore
+class TreebeardConfig(BaseModel):
     notebook: str = "main.ipynb"
+    output_dirs: Tuple[str, ...] = tuple("output")
     ignore: Tuple[str, ...] = ()
     secret: Tuple[str, ...] = ()
 
