@@ -8,9 +8,13 @@ from halo import Halo  # type: ignore
 from humanfriendly import format_size, parse_size  # type: ignore
 from timeago import format as timeago_format  # type: ignore
 
-from treebeard.cli_helper import check_for_updates, get_service_status_message
 from treebeard.conf import service_status_endpoint
-from treebeard.helper import get_config_path, get_treebeard_env
+from treebeard.helper import (
+    get_config_path,
+    get_treebeard_env,
+    check_for_updates,
+    get_service_status_message,
+)
 from treebeard.notebooks.commands import cancel, run, status
 from treebeard.other.commands import configure, info, version
 from treebeard.secrets.commands import secrets
